import React, { forwardRef, useRef, useEffect } from "react";
const BootstrapDragHandle = forwardRef(({ className, title }, dragRef) => /* @__PURE__ */ React.createElement("span", {
  ref: dragRef,
  className,
  title
}, /* @__PURE__ */ React.createElement("i", {
  className: "bi bi-grip-vertical"
})));
BootstrapDragHandle.displayName = "BootstrapDragHandle";
const BootstrapNotToggle = ({
  className,
  handleOnChange,
  title,
  label,
  checked,
  disabled
}) => {
  const id = useRef(`notToggle-${Math.random()}`);
  return /* @__PURE__ */ React.createElement("div", {
    className: `form-check-inline form-switch ${className}`
  }, /* @__PURE__ */ React.createElement("input", {
    id: id.current,
    className: "form-check-input",
    type: "checkbox",
    onChange: (e) => handleOnChange(e.target.checked),
    checked: !!checked,
    disabled
  }), /* @__PURE__ */ React.createElement("label", {
    title,
    htmlFor: id.current,
    className: "form-check-label"
  }, label));
};
BootstrapNotToggle.displayName = "BootstrapNotToggle";
const BootstrapValueEditor = ({
  fieldData,
  operator,
  value,
  handleOnChange,
  title,
  className,
  type,
  inputType,
  values,
  disabled
}) => {
  var _a;
  useEffect(() => {
    if (inputType === "number" && !["between", "notBetween", "in", "notIn"].includes(operator) && typeof value === "string" && value.includes(",")) {
      handleOnChange("");
    }
  }, [inputType, operator, value, handleOnChange]);
  if (operator === "null" || operator === "notNull") {
    return null;
  }
  const placeHolderText = (_a = fieldData == null ? void 0 : fieldData.placeholder) != null ? _a : "";
  const inputTypeCoerced = ["between", "notBetween", "in", "notIn"].includes(operator) ? "text" : inputType || "text";
  switch (type) {
    case "select":
      return /* @__PURE__ */ React.createElement("select", {
        className: `${className} form-select form-select-sm`,
        title,
        onChange: (e) => handleOnChange(e.target.value),
        value,
        disabled
      }, values.map((v) => /* @__PURE__ */ React.createElement("option", {
        key: v.name,
        value: v.name
      }, v.label)));
    case "checkbox":
      return /* @__PURE__ */ React.createElement("input", {
        type: "checkbox",
        className: `form-check-input ${className}`,
        title,
        disabled,
        onChange: (e) => handleOnChange(e.target.checked),
        checked: !!value
      });
    case "radio":
      return /* @__PURE__ */ React.createElement("span", {
        title
      }, values.map((v) => /* @__PURE__ */ React.createElement("div", {
        key: v.name,
        className: "form-check form-check-inline"
      }, /* @__PURE__ */ React.createElement("input", {
        className: "form-check-input",
        type: "radio",
        id: v.name,
        value: v.name,
        checked: value === v.name,
        disabled,
        onChange: (e) => handleOnChange(e.target.value)
      }), /* @__PURE__ */ React.createElement("label", {
        className: "form-check-label",
        htmlFor: v.name
      }, v.label))));
    default:
      return /* @__PURE__ */ React.createElement("input", {
        type: inputTypeCoerced,
        value,
        title,
        className,
        disabled,
        placeholder: placeHolderText,
        onChange: (e) => handleOnChange(e.target.value)
      });
  }
};
BootstrapValueEditor.displayName = "ValueEditor";
export { BootstrapDragHandle, BootstrapNotToggle, BootstrapValueEditor };
